Struct StyleLayerInfo
#[non_exhaustive]pub struct StyleLayerInfo {
pub id: String,
pub layer_type: String,
pub source_id: Option<String>,
pub source_layer: Option<String>,
}Expand description
Copied identity and source binding for one style layer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Stringlayer_type: StringStyle-spec layer type, such as line or background.
source_id: Option<String>Source ID, or None when the layer type takes no source.
source_layer: Option<String>Source-layer, or None when the layer names none.