#[non_exhaustive]pub struct CustomMvtVectorSourceOptions {
pub min_zoom: Option<f64>,
pub max_zoom: Option<f64>,
/* private fields */
}Expand description
Options used when adding a custom MVT vector source.
Custom MVT vector callbacks may run on native worker threads. Keep callbacks
quick, and hand work back to the map owner thread before calling map APIs
such as set_custom_mvt_vector_source_tile_data or
set_custom_mvt_vector_source_tile_error.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.min_zoom: Option<f64>Minimum zoom level at which the source produces tiles.
max_zoom: Option<f64>Maximum zoom level at which the source produces tiles.
Implementations
Sourceimpl CustomMvtVectorSourceOptions
impl CustomMvtVectorSourceOptions
pub fn new<F>(fetch_tile: F) -> Self
pub fn with_cancel_tile<F>(self, cancel_tile: F) -> Self