RuntimeEventMask

Struct RuntimeEventMask 

pub struct RuntimeEventMask(/* private fields */);
Event types a map or a runtime queues.

Each bit is 1 << RuntimeEventType::raw_value, so a bit derived from a decoded event type matches the constant that names it. A map reads the bits in ALL_MAP_EVENTS and a runtime reads the bits in ALL_RUNTIME_EVENTS, so both accept ALL.

Implementations



impl RuntimeEventMask

pub const NONE: RuntimeEventMask

Selects no event type.

pub const MAP_CAMERA_WILL_CHANGE: RuntimeEventMask

pub const MAP_CAMERA_IS_CHANGING: RuntimeEventMask

pub const MAP_CAMERA_DID_CHANGE: RuntimeEventMask

pub const MAP_CAMERA_TRANSITION_FINISHED: RuntimeEventMask

pub const MAP_STYLE_LOADED: RuntimeEventMask

pub const MAP_LOADING_STARTED: RuntimeEventMask

pub const MAP_LOADING_FINISHED: RuntimeEventMask

pub const MAP_LOADING_FAILED: RuntimeEventMask

pub const MAP_IDLE: RuntimeEventMask

pub const MAP_RENDER_UPDATE_AVAILABLE: RuntimeEventMask

pub const MAP_RENDER_ERROR: RuntimeEventMask

pub const MAP_STILL_IMAGE_FINISHED: RuntimeEventMask

pub const MAP_STILL_IMAGE_FAILED: RuntimeEventMask

pub const MAP_RENDER_FRAME_STARTED: RuntimeEventMask

pub const MAP_RENDER_FRAME_FINISHED: RuntimeEventMask

pub const MAP_RENDER_MAP_STARTED: RuntimeEventMask

pub const MAP_RENDER_MAP_FINISHED: RuntimeEventMask

pub const MAP_STYLE_IMAGE_MISSING: RuntimeEventMask

pub const MAP_TILE_ACTION: RuntimeEventMask

pub const OFFLINE_REGION_STATUS_CHANGED: RuntimeEventMask

pub const OFFLINE_REGION_RESPONSE_ERROR: RuntimeEventMask

pub const OFFLINE_REGION_TILE_COUNT_LIMIT_EXCEEDED: RuntimeEventMask

pub const OFFLINE_OPERATION_COMPLETED: RuntimeEventMask

pub const ALL_MAP_EVENTS: RuntimeEventMask

Selects every map-originated event type this version defines.

pub const ALL_RUNTIME_EVENTS: RuntimeEventMask

Selects every runtime-originated event type this version defines.

pub const ALL: RuntimeEventMask

Selects every event type this version defines.



impl RuntimeEventMask

pub const fn empty() -> RuntimeEventMask

Get a flags value with all bits unset.

pub const fn all() -> RuntimeEventMask

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<RuntimeEventMask>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> RuntimeEventMask

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> RuntimeEventMask

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<RuntimeEventMask>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: RuntimeEventMask) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: RuntimeEventMask) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: RuntimeEventMask)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: RuntimeEventMask)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: RuntimeEventMask)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: RuntimeEventMask, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: RuntimeEventMask) -> RuntimeEventMask

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: RuntimeEventMask) -> RuntimeEventMask

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: RuntimeEventMask) -> RuntimeEventMask

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference( self, other: RuntimeEventMask, ) -> RuntimeEventMask

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> RuntimeEventMask

The bitwise negation (!) of the bits in self, truncating the result.



impl RuntimeEventMask

pub const fn iter(&self) -> Iter<RuntimeEventMask>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<RuntimeEventMask>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.