Enum RenderResult
#[non_exhaustive]pub enum RenderResult {
Rendered,
NoUpdate,
SizePending,
TargetNotReady,
Unknown(u32),
}Expand description
Outcome of a successful render-update call.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Rendered
The call rendered a frame into the render target.
NoUpdate
The call produced no frame. Wait for a render-update-available event.
SizePending
The map has not applied the session’s current size yet. Wait for the next render-update-available event.
TargetNotReady
The render target had no frame to draw into. Wait for a host event that changes the target, or back off and retry.
Unknown(u32)
Implementations
impl RenderResult
impl RenderResult
pub fn from_raw(raw: u32) -> RenderResult