Struct ScreenBox
pub struct ScreenBox {
pub min: ScreenPoint,
pub max: ScreenPoint,
}Expand description
Screen-space box in logical map pixels.
Corners may be given in any order, and may extend past the viewport. Rendered queries normalize the corners and clip the box to the viewport, so a box that over-covers the viewport queries everything visible.
Fields
min: ScreenPointmax: ScreenPointImplementations
impl ScreenBox
impl ScreenBox
pub const fn new(min: ScreenPoint, max: ScreenPoint) -> ScreenBox