pub enum OfflineOperationTakeError<T> {
Retryable(HandleOperationError<T>),
Consumed(Error),
}Expand description
Error returned by offline operation result transfers.
Variants
Retryable(HandleOperationError<T>)
The native transfer failed before consuming the operation result.
Consumed(Error)
The native result was consumed, but copying it into Rust-owned data failed.
Implementations
Sourceimpl<T> OfflineOperationTakeError<T>
impl<T> OfflineOperationTakeError<T>
Sourcepub fn raw_status(&self) -> Option<i32>
pub fn raw_status(&self) -> Option<i32>
Returns the raw C status for native operation errors, when available.
Sourcepub fn diagnostic(&self) -> &str
pub fn diagnostic(&self) -> &str
Returns the copied diagnostic message for the operation error.
Sourcepub fn into_retryable(self) -> Option<HandleOperationError<T>>
pub fn into_retryable(self) -> Option<HandleOperationError<T>>
Returns the retryable error and still-live handle, if the operation was not consumed.
Sourcepub fn into_error(self) -> Error
pub fn into_error(self) -> Error
Returns the operation error, dropping any retryable handle.