CustomGeometrySourceOptions

Struct CustomGeometrySourceOptions 

#[non_exhaustive]
pub struct CustomGeometrySourceOptions { pub min_zoom: Option<f64>, pub max_zoom: Option<f64>, pub tolerance: Option<f64>, pub tile_size: Option<u32>, pub buffer: Option<u32>, pub clip: Option<bool>, pub wrap: Option<bool>, /* private fields */ }
Options used when adding a custom geometry source.

Custom geometry callbacks may run on native worker threads. Keep callbacks quick, and hand work back to the map owner thread before calling map APIs such as set_custom_geometry_source_tile_data or invalidation helpers.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
min_zoom: Option<f64>

Minimum zoom level at which the source produces tiles.

max_zoom: Option<f64>

Maximum zoom level at which the source produces tiles.

tolerance: Option<f64>

Douglas-Peucker simplification tolerance in tile coordinate units.

tile_size: Option<u32>

Tile extent in pixels, usually 512.

buffer: Option<u32>

Extra tile buffer in pixels for geometry that crosses tile edges.

clip: Option<bool>

Whether native clips geometries to tile bounds.

wrap: Option<bool>

Whether the source wraps horizontally across the antimeridian.

Implementations

Source

impl CustomGeometrySourceOptions

pub fn new<F>(fetch_tile: F) -> Self
where F: Fn(CanonicalTileId) + Send + Sync + 'static,

pub fn with_cancel_tile<F>(self, cancel_tile: F) -> Self
where F: Fn(CanonicalTileId) + Send + Sync + 'static,

pub fn with_min_zoom(self, min_zoom: f64) -> Self

pub fn with_max_zoom(self, max_zoom: f64) -> Self

pub fn with_tolerance(self, tolerance: f64) -> Self

pub fn with_tile_size(self, tile_size: u32) -> Self

pub fn with_buffer(self, buffer: u32) -> Self

pub fn with_clip(self, clip: bool) -> Self

pub fn with_wrap(self, wrap: bool) -> Self