pub struct HandleOperationError<T> { /* private fields */ }Expand description
Error returned by consuming one-shot handle operations when the handle remains live and the operation can be retried.
Implementations
Sourceimpl<T> HandleOperationError<T>
impl<T> HandleOperationError<T>
Sourcepub fn raw_status(&self) -> Option<mln_status>
pub fn raw_status(&self) -> Option<mln_status>
Returns the raw C status for native operation errors, when available.
Sourcepub fn diagnostic(&self) -> &str
pub fn diagnostic(&self) -> &str
Returns the copied diagnostic message for the operation error.
Sourcepub fn into_error(self) -> Error
pub fn into_error(self) -> Error
Returns the operation error, dropping the still-live handle.
Sourcepub fn into_handle(self) -> T
pub fn into_handle(self) -> T
Returns the still-live handle so the operation can be retried.
Sourcepub fn into_parts(self) -> (Error, T)
pub fn into_parts(self) -> (Error, T)
Splits this error into the operation error and still-live handle.