Enum SourceType
#[non_exhaustive]pub enum SourceType {
Unknown,
Vector,
Raster,
RasterDem,
GeoJson,
Image,
Video,
Annotations,
CustomVector,
Other(u32),
}Expand description
Style source type values returned by native style source metadata.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
impl SourceType
impl SourceType
pub fn from_raw(raw: u32) -> SourceType
pub fn from_raw(raw: u32) -> SourceType
Converts a raw C ABI source type value into a Rust value, preserving future values.